tlslite.utils

Package tlslite :: Package utils |
[show private | hide private]
[frames | no frames]

## Package tlslite.utils

Toolkit for crypto and other stuff.

Submodules
`AES`: Abstract class for AES. `ASN1Parser`: Class for parsing ASN.1 `cipherfactory`: Factory functions for symmetric cryptography. `codec`: Classes for reading/writing binary data (such as TLS records). `compat`: Miscellaneous functions to mask Python version differences. `Cryptlib_AES`: Cryptlib AES implementation. `Cryptlib_RC4`: Cryptlib RC4 implementation. `Cryptlib_TripleDES`: Cryptlib 3DES implementation. `dateFuncs` `hmac`: HMAC (Keyed-Hashing for Message Authentication) Python module. `keyfactory`: Factory functions for asymmetric cryptography. `OpenSSL_AES`: OpenSSL/M2Crypto AES implementation. `OpenSSL_RC4`: OpenSSL/M2Crypto RC4 implementation. `OpenSSL_RSAKey`: OpenSSL/M2Crypto RSA implementation. `OpenSSL_TripleDES`: OpenSSL/M2Crypto 3DES implementation. `PyCrypto_AES`: PyCrypto AES implementation. `PyCrypto_RC4`: PyCrypto RC4 implementation. `PyCrypto_RSAKey`: PyCrypto RSA implementation. `PyCrypto_TripleDES`: PyCrypto 3DES implementation. `Python_AES`: Pure-Python AES implementation. `Python_RC4`: Pure-Python RC4 implementation. `Python_RSAKey`: Pure-Python RSA implementation. `RC4`: Abstract class for RC4. `rijndael`: A pure python (slow) implementation of rijndael with a decent interface `RSAKey`: Abstract class for RSA. `TripleDES`: Abstract class for 3DES. `xmltools`: Helper functions for XML. `cryptomath`: cryptomath module `jython_compat`: Miscellaneous functions to mask Python/Jython differences.

Generated by Epydoc 2.0 on Mon Feb 21 21:56:54 2005 | http://epydoc.sf.net